@@ -8,9 +8,10 @@ This module contains the classes necessary to handle both
 It also contains a decorator to mark methods as rpc methods.
 '''
 
-import platform
 import inspect
+import platform
 import pydoc
+import types
 import xmlrpclib
 from xmlrpclib import Fault
 from jsonrpcdispatcher import JSONRPCDispatcher, json
@@ -236,7 +237,15 @@ class RPCDispatcher:
                    getattr(method, 'is_rpcmethod', False):
                     # if this method is callable and it has the rpcmethod
                     # decorator, add it to the dispatcher
-                    self.register_method(method, method.external_name)     
+                    self.register_method(method, method.external_name)
+                elif isinstance(method, types.ModuleType):
+                    # if this is not a method and instead a sub-module,
+                    # scan the module for methods with @rpcmethod
+                    try:
+                        self.register_rpcmethods(["%s.%s" % (appname, obj)])
+                    except ImportError:
+                        pass
+
     
     def jsondispatch(self, raw_post_data, **kwargs):
         '''
@@ -288,9 +297,11 @@ class RPCDispatcher:
         '''
         Registers a method with the rpc server
         '''
-        
+
         meth = RPCMethod(method, name, signature, helpmsg)
-        self.xmlrpcdispatcher.register_function(method, meth.name)
-        self.jsonrpcdispatcher.register_function(method, meth.name)
-        self.rpcmethods.append(meth)
+        
+        if meth.name not in self.system_listmethods():
+            self.xmlrpcdispatcher.register_function(method, meth.name)
+            self.jsonrpcdispatcher.register_function(method, meth.name)
+            self.rpcmethods.append(meth)
     
