@@ -222,7 +222,7 @@ except ImportError:
         csrf_exempt = None
 
 if csrf_exempt is not None:
-    csrf_exempt(serve_rpc_request)
+    serve_rpc_request = csrf_exempt(serve_rpc_request)
 
     
 # instantiate the rpcdispatcher -- this examines the INSTALLED_APPS
